@@ -10,20 +10,20 @@
 #include <custom_conf.h>
 #else
 #define PROTOCOL_VERSION		10
-#define MARIADB_CLIENT_VERSION_STR	"10.4.12"
+#define MARIADB_CLIENT_VERSION_STR	"10.4.13"
 #define MARIADB_BASE_VERSION		"mariadb-10.4"
-#define MARIADB_VERSION_ID		100412
+#define MARIADB_VERSION_ID		100413
 #define MARIADB_PORT	        	3306
 #define MARIADB_UNIX_ADDR               "/var/run/mysql/mysql.sock"
 
 #define MYSQL_CONFIG_NAME               "my"
-#define MYSQL_VERSION_ID                100412
-#define MYSQL_SERVER_VERSION            "10.4.12-MariaDB"
+#define MYSQL_VERSION_ID                100413
+#define MYSQL_SERVER_VERSION            "10.4.13-MariaDB"
 
-#define MARIADB_PACKAGE_VERSION "3.1.7"
-#define MARIADB_PACKAGE_VERSION_ID 30107
+#define MARIADB_PACKAGE_VERSION "3.1.8"
+#define MARIADB_PACKAGE_VERSION_ID 30108
 #define MARIADB_SYSTEM_TYPE "OpenBSD"
-#define MARIADB_MACHINE_TYPE "i386"
+#define MARIADB_MACHINE_TYPE "sparc64"
 #define MARIADB_PLUGINDIR "/usr/local/lib/mysql/plugin"
 
 /* mysqld compile time options */
